==> fred-backend-fileman_0.1.0.orig.tar.gz: fred-backend-fileman-0.1.0/fileman/commands/server.py <==
#!/usr/bin/python3
"""Run fileman gRPC server.

Usage: fred-fileman-server [options]
       fred-fileman-server -h | --help
       fred-fileman-server --version

Options:
  -h, --help                show this help message and exit
  --version                 show program's version number and exit
  --config=FILE             set custom config file
  -p, --port=PORT           set custom port
  --connection=CONNECTION   set custom database connection string
  --poolclass=POOLCLASS     set custom pool class
  --storage=STORAGE         set custom storage root
  --max-workers=NUM         set maximum number of workers
"""
from concurrent.futures import ThreadPoolExecutor
from importlib import import_module
from time import sleep
from typing import Iterable

import grpc
from docopt import docopt
from fred_api.fileman.service_fileman_grpc_pb2_grpc import add_FileServicer_to_server
from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker

import fileman
from fileman.service import FileServicer
from fileman.settings import SETTINGS


def main(argv: Iterable[str] = None):
    """Start the server."""
    options = docopt(__doc__, argv=argv, version=fileman.__version__)
    SETTINGS.load(options['--config'])
    SETTINGS.set_options(options)

    if SETTINGS['max_workers'] is None:
        max_workers = None
    else:
        max_workers = int(SETTINGS['max_workers'])
    server = grpc.server(ThreadPoolExecutor(max_workers))
    if SETTINGS['db_poolclass']:
        try:
            module_name, class_name = SETTINGS['db_poolclass'].rsplit('.', 1)
            kwargs = {'poolclass': getattr(import_module(module_name), class_name)}
        except (ImportError, AttributeError, ValueError):
            exit("'{}' was not found.".format(SETTINGS['db_poolclass']))
    else:
        kwargs = {}
    engine = create_engine(SETTINGS['db_connection'], **kwargs)
    add_FileServicer_to_server(FileServicer(SETTINGS['storage_root'], sessionmaker(bind=engine)), server)
    server.add_insecure_port('[::]:{port}'.format(port=SETTINGS['grpc_port']))
    server.start()
    # Sadly this is the recommended way to keep the server running.
    try:
        while True:
            sleep(86400)
    except KeyboardInterrupt:
        server.stop(0)


if __name__ == '__main__':
    main()

==> fred-backend-fileman_0.3.0.orig.tar.gz: fred-backend-fileman-0.3.0/fileman/commands/server.py <==
#!/usr/bin/python3
"""Run fileman gRPC server.

Usage: fred-fileman-server [options]
       fred-fileman-server -h | --help
       fred-fileman-server --version

Options:
  -h, --help                show this help message and exit
  --version                 show program's version number and exit
  --config=FILE             set custom config file
  -p, --port=PORT           set custom port
  --connection=CONNECTION   set custom database connection string
  --poolclass=POOLCLASS     set custom pool class
  --storage=STORAGE         set custom storage root
  --max-workers=NUM         set maximum number of workers
"""
from concurrent.futures import ThreadPoolExecutor
from importlib import import_module
from time import sleep
from typing import Iterable, Optional

import grpc
from docopt import docopt
from fred_api.fileman.service_fileman_grpc_pb2_grpc import add_FileServicer_to_server
from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker

import fileman
from fileman.service import FileServicer
from fileman.settings import SETTINGS


def main(argv: Optional[Iterable[str]] = None) -> None:
    """Start the server."""
    options = docopt(__doc__, argv=argv, version=fileman.__version__)
    SETTINGS.load(options['--config'])
    SETTINGS.set_options(options)

    if SETTINGS['max_workers'] is None:
        max_workers = None
    else:
        max_workers = int(SETTINGS['max_workers'])
    server = grpc.server(ThreadPoolExecutor(max_workers))
    if SETTINGS['db_poolclass']:
        try:
            module_name, class_name = SETTINGS['db_poolclass'].rsplit('.', 1)
            kwargs = {'poolclass': getattr(import_module(module_name), class_name)}
        except (ImportError, AttributeError, ValueError):
            exit("'{}' was not found.".format(SETTINGS['db_poolclass']))
    else:
        kwargs = {}
    engine = create_engine(SETTINGS['db_connection'], **kwargs, future=True)
    add_FileServicer_to_server(FileServicer(SETTINGS['storage_root'], sessionmaker(bind=engine, future=True)), server)
    server.add_insecure_port('[::]:{port}'.format(port=SETTINGS['grpc_port']))
    server.start()
    # Sadly this is the recommended way to keep the server running.
    try:
        while True:
            sleep(86400)
    except KeyboardInterrupt:
        server.stop(0)


if __name__ == '__main__':
    main()
